Module node

Module node 

Structs

ConditionalBranch

Enums

EvalOnFail
What the eval node does when one or more scorers fail.
EvalScorer
A scorer within an Eval node.
FinalizerTrigger
MergeStrategy
NodeKind
All node kinds supported by the JamJet runtime.
NodeStatus
The lifecycle status of a single node within an execution.
QueueType
Which queue a node’s work item is dispatched to.
ViolationAction
WaitCondition

Type Aliases

NodeId